#!/usr/bin/python
# -*- coding: utf-8 -*-
### BEGIN LICENSE
# Copyright (C) 2013 ~ 2014 National University of Defense Technology(NUDT) & Kylin Ltd
#
# Authors:
# Kobe Lee    lixiang@kylinos.cn/xiangli@ubuntukylin.com/kobe24_lixiang@126.com
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import os, sys
import re
import binascii
import threading
import platform
import signal
import commands
import dbus
import dbus.service
import dbus.mainloop.glib
import math
from gi.repository import GLib, GObject
import apt
import gettext
locale_path = '/usr/share/locale/'

CPU_MAX_FREQ = "/sys/devices/system/cpu/cpu0/cpufreq/scaling_max_freq"
MEMORY = "/sys/phytium1500a_info"
RELEASEPATH = "/etc/lsb-release"
OSPATH = "/etc/os-release"

KILOBYTE_FACTOR = 1000.0
MEGABYTE_FACTOR = (1000.0 * 1000.0)
GIGABYTE_FACTOR = (1000.0 * 1000.0 * 1000.0)
TERABYTE_FACTOR = (1000.0 * 1000.0 * 1000.0 * 1000.0)

MEM_KILOBYTE_FACTOR = 1024.0
MEM_MEGABYTE_FACTOR = (1024.0 * 1024.0)
MEM_GIGABYTE_FACTOR = (1024.0 * 1024.0 * 1024.0)
MEM_TERABYTE_FACTOR = (1024.0 * 1024.0 * 1024.0 * 1024.0)

def get_human_read_capacity_size(size):
    '''
    将容量大小转换为用户可以理解的值和单位
    '''
    size_str = ""
    displayed_size = 0.0
    unit = "KB"

    if size < MEGABYTE_FACTOR:
        displayed_size = float(size/KILOBYTE_FACTOR)
        unit = "KB"
    elif size < GIGABYTE_FACTOR:
        displayed_size = float(size/MEGABYTE_FACTOR)
        unit = "MB"
    elif size < TERABYTE_FACTOR:
        displayed_size = float(size/GIGABYTE_FACTOR)
        unit = "GB"
    else:
        displayed_size = float(size/TERABYTE_FACTOR)
        unit = "TB"
    #print "displayed_size=", round(displayed_size)
    #round 不是简单的四舍五入，而是ROUND_HALF_EVEN的策略
    #ceil 取大于或者等于x的最小整数
    #floor 取小于或者等于x的最大整数
    #print round(2.5)#3.0
    #print math.ceil(2.5)#3.0
    #print math.floor(2.5)#2.0
    #print round(2.3)#2.0
    #print math.ceil(2.3)#3.0
    #print math.floor(2.3)#2.0
    str_list = [str(int(round(displayed_size))), unit]
    size_str = " ".join(str_list)
    return size_str

def get_mem_human_read_capacity_size(size):
    '''
    将容量大小转换为用户可以理解的值和单位
    '''
    size_str = ""
    displayed_size = 0.0
    unit = "KB"

    if size < MEM_MEGABYTE_FACTOR:
        displayed_size = float(size/MEM_KILOBYTE_FACTOR)
        unit = "KB"
    elif size < MEM_GIGABYTE_FACTOR:
        displayed_size = float(size/MEM_MEGABYTE_FACTOR)
        unit = "MB"
    elif size < MEM_TERABYTE_FACTOR:
        displayed_size = float(size/MEM_GIGABYTE_FACTOR)
        unit = "GB"
    else:
        displayed_size = float(size/MEM_TERABYTE_FACTOR)
        unit = "TB"
    str_list = [str(int(math.ceil(displayed_size))), unit]
    size_str = " ".join(str_list)
    return size_str

#def ctoascii(buf):
#    ch = str(buf)
#    asci = binascii.b2a_hex(ch)
#    asci = int(asci,16)
#    return asci

#def mystrip(s):
#    if(len(s) == 0):
#        return s
#    while len(s) > 0 and ctoascii(s[0]) <= 32:
#        s = s[1: ]
#    k = len(s)
#    while len(s) > 0 and ctoascii(s[k-1]) <= 32:
#        s = s[ :k-1]
#        k = len(s)
#    i = 0
#    while i < len(s):
#        if s[i] < 32:
#            s = s[ :i] + s[i+1: ]
#            i -= 1
#        i += 1
#    return s

#def get_cpu_info():
#    Cpu = {}
#    machine = platform.machine()
#    if machine == "aarch64":
#        if os.path.exists(CPU_MAX_FREQ):
#            fp = open(CPU_MAX_FREQ, "r")
#            info = fp.read()
#            tmp = float(info.strip()) / (1000 * 1000)
#            freq = str("%.1f" % tmp)
#            fp.close()
#            Cpu['CpuVersion'] = "1500a v1.0"
#            Cpu['CpuVendor'] = _("phytium")#phytium(飞腾)
#            Cpu['CpuCapacity'] = "%s GHz" % freq
#            Cpu['cpu_cores'] = "4 cores"#4 核
#            Cpu['cpu_siblings'] = "4 thread/core"#4 线程/核
#            Cpu['clflush_size'] = "32 KB"
#            Cpu['cache_size'] = "2 MB"
#        else:
#            #处理器版本
#            Cpu['CpuVersion'] = "1500a v1.0"
#            #制造商 phytium
#            Cpu['CpuVendor'] = _("phytium")#phytium(飞腾)
#            #最大主频
#            Cpu['CpuCapacity'] = "1800 MHz"
#            #内核数
#            Cpu['cpu_cores'] = _("4 cores")#4 核
#            #线程
#            Cpu['cpu_siblings'] = _("4 thread/core")#4 线程/核
#            #一级缓存
#            Cpu['clflush_size'] = "32 KB"
#            #二级缓存
#            Cpu['cache_size'] = "2 MB"
#    else:
#        hw = os.popen("dmidecode -t processor")
#        cpuin = hw.read()
#        hw.close()
#        CpuVersion,CpuVendor,CpuSlot,CpuSerial,CpuCapacity,CpuSize,CpuClock,cpu_cores,cpu_siblings,clflush_size,cache_size = '','','','','','','','','','',''
#        if cpuin :
#            tmp = re.findall("Version: (.*)",cpuin)
#            if tmp:
#                CpuVersion = tmp[0]
#            tmp = re.findall("Manufacturer: (.*)",cpuin)
#            if tmp :
#                CpuVendor = tmp[0]
#            tmp = re.findall("Socket Designation: (.*)",cpuin)
#            if tmp :
#                CpuSlot = tmp[0]
#            tmp = re.findall("Serial Number: (.*)",cpuin)
#            if tmp :
#                CpuSerial = tmp[0]
#            tmp = re.findall("Max Speed: (.*)",cpuin)
#            if tmp :
#                CpuCapacity = tmp[0]
#            tmp = re.findall("Current Speed: (.*)",cpuin)
#            if tmp :
#                CpuSize = tmp[0]
#            tmp = re.findall("External Clock: (.*)",cpuin)
#            if tmp :
#                CpuClock = tmp[0]
#        #CpuVendor = self.get_url(CpuVendor,CpuVersion)
#        Cpu['CpuVersion'],Cpu['CpuVendor'],Cpu['CpuSlot'],Cpu['CpuSerial'],Cpu['CpuCapacity'],Cpu['CpuSize'],Cpu['CpuClock'] = mystrip(CpuVersion),mystrip(CpuVendor),mystrip(CpuSlot),mystrip(CpuSerial),mystrip(CpuCapacity),mystrip(CpuSize),mystrip(CpuClock)
#        with open('/proc/cpuinfo') as f:
#            for line in f:
#                if line.strip():
#                    if line.rstrip('\n').startswith('vendor_id'):
#                        vendor = line.rstrip('\n').split(':')[1]
#                    elif line.rstrip('\n').startswith('cpu cores'):
#                        cpu_cores = line.rstrip('\n').split(':')[1]
#                    elif line.rstrip('\n').startswith('siblings'):
#                        cpu_siblings = line.rstrip('\n').split(':')[1]
#                    elif line.rstrip('\n').startswith('clflush size'):
#                        clflush_size = line.rstrip('\n').split(':')[1]
#                        clflush_size = filter(str.isdigit,clflush_size)
#                    elif line.rstrip('\n').startswith('cache size'):
#                        cache_size = line.rstrip('\n').split(':')[1]
#                        cache_size = filter(str.isdigit,cache_size)
#        Cpu['cpu_cores'],Cpu['cpu_siblings'],Cpu['clflush_size'],Cpu['cache_size'] = cpu_cores,cpu_siblings,clflush_size,cache_size
#    print Cpu


#def get_memory_info():
#    Mem = {}
#    machine = platform.machine()
#    if machine == "aarch64":
#        if os.path.exists(MEMORY):
#            memnum = 0
#            all_exists = []
#            total = [ f for f in os.listdir(MEMORY) if f.startswith("memory")]

#            for p in total:
#                exists = os.path.join(MEMORY, p)
#                if os.stat(exists).st_size:
#                    all_exists.append(exists)

#            for i in all_exists:
#                fp = open(i, "r")
#                info = fp.read()
#                fp.close
#                dic = dict([tuple(x.split(":")) for x in info.split("\n") if x and ":" in x])
#                if dic in (None, {}):
#                    continue
#                else:
#                    memnum += 1
#                if Mem.get("MemSlot") == None:
#                    Mem["MemSlot"] = dic["Bank Locator"]
#                else:
#                    Mem["MemSlot"] +=  "<1_1>" + str(dic["Bank Locator"])
#                if Mem.get("MemSize") == None:
#                    Mem["MemSize"] = dic["Size"]
#                else:
#                    Mem["MemSize"] += "<1_1>" + str(dic["Size"])
#                if Mem.get("MemVendor") == None:
#                    Mem["MemVendor"] = str(dic["Manufacturer ID"].upper())
#                else:
#                    Mem["MemVendor"] += "<1_1>" + str(dic["Manufacturer ID"].upper())
#                if Mem.get("MemWidth") == None:
#                    Mem["MemWidth"] = "64 bits"
#                else:
#                    Mem["MemWidth"] += "<1_1>" + "64 bits"
#            Mem["Memnum"] = str(memnum)
#        else:
#            Mem["Memnum"] = "1"
#            Mem["MemWidth"] = "64 bits"
#            Mem["MemInfo"] = "DDR3"
#            fp = open("/proc/meminfo", "r")
#            info = fp.read()
#            fp.close()
#            dic = dict([tuple(x.split(":")) for x in info.split("\n") if x])
#            Mem["MemSize"] = dic["MemTotal"].strip()
#    else:
#        MemInfo,MemWidth,Memnum,MemSlot,MemProduct,MemVendor,MemSerial,MemSize,BioVendor = "","","","","","",'','',''
#        hw = os.popen("dmidecode -t memory")
#        memory = hw.read()
#        hw.close()
#        num = 0
#        q = re.findall('Memory Device\n',memory)
#        if q :
#            memory = memory[memory.index("Memory Device\n")+len("Memory Device\n"):]
#        else :
#            memory = ''
#        if memory :
#            mark = re.findall("Data Width: (.*)",memory)
#            if mark :
#                for k in mark :
#                    if not k == 'Unknown':
#                        num += 1
#                        if MemWidth:
#                            MemWidth += "<1_1>" + k
#                        else:
#                            MemWidth = k
#            Memnum = str(num)
#            tmp = re.findall("Bank Locator: (.*)",memory)
#            i = 0
#            if tmp :
#                for k in mark :
#                    i += 1
#                    if not k == 'Unknown':
#                        if MemSlot :
#                            MemSlot +="<1_1>"+ tmp[i-1]
#                        else :
#                            MemSlot = tmp[i-1]
#            tmp = re.findall("Part Number: (.*)",memory)
#            i = 0
#            if tmp :
#                for k in mark :
#                    i += 1
#                    if not k == 'Unknown':
#                        if MemProduct :
#                            MemProduct += "<1_1>" + tmp[i-1]
#                        else :
#                            MemProduct = tmp[i-1]
#            tmp = re.findall("Manufacturer: (.*)",memory)
#            i = 0
#            if tmp :
#                for k in mark :
#                    i += 1
#                    if not k == 'Unknown':
#                        if MemVendor :
#                            MemVendor += "<1_1>" + tmp[i-1]
#                        else :
#                            MemVendor = tmp[i-1]
#            tmp = re.findall("Serial Number: (.*)",memory)
#            i = 0
#            if tmp :
#                for k in mark :
#                    i += 1
#                    if not k == 'Unknown':
#                        if MemSerial :
#                            MemSerial += "<1_1>" + tmp[i-1]
#                        else :
#                            MemSerial = tmp[i-1]
#            tmp = re.findall("Size: (.*)",memory)
#            i = 0
#            if tmp :
#                for k in mark :
#                    i += 1
#                    if not k == 'Unknown':
#                        if MemSize :
#                            MemSize += "<1_1>" + tmp[i-1]
#                        else :
#                            MemSize = tmp[i-1]
#            tmp0 = mystrip(re.findall("Form Factor: (.*)",memory))
#            tmp1 = mystrip(re.findall("Type: (.*)",memory))
#            tmp2 = mystrip(re.findall("Type Detail: (.*)",memory))
#            tmp3 = mystrip(re.findall("Speed: (.*)",memory))
#            i = 0
#            if tmp0 and tmp1 and tmp2 and tmp3 :
#                for k in mark :
#                    i += 1
#                    if not k == 'Unknown':
#                        if MemInfo :
#                            MemInfo += "<1_1>" + tmp0[i-1] + ' ' + tmp1[i-1] + ' ' + tmp2[i-1] + ' ' + tmp3[i-1]
#                        else :
#                            MemInfo = tmp0[i-1] + ' ' + tmp1[i-1] + ' ' + tmp2[i-1] + ' ' + tmp3[i-1]
#        Mem["MemInfo"],Mem["MemWidth"],Mem["MemSlot"],Mem["MemProduct"],Mem["MemVendor"],Mem["MemSerial"],Mem["MemSize"],Mem["Memnum"] = MemInfo,mystrip(MemWidth),mystrip(MemSlot),mystrip(MemProduct),mystrip(MemVendor),mystrip(MemSerial),mystrip(MemSize),mystrip(Memnum)
#    print Mem

#def get_user_info():
    #print GLib.get_user_name()
    #print GLib.get_home_dir()
    #print GLib.getenv('SHELL')
    #print GLib.getenv('LANG')

#def get_distro():
#   a = platform.dist()[0]
#   b = platform.dist()[1]
#   c = platform.dist()[2]
#   distro = '-'.join((a,b,c))
#   print distro

def get_os():
    '''
    获取操作系统信息
    '''
    os_name = None
    release_name = None
    if os.path.exists(OSPATH):
        with open(OSPATH, "r") as fsys:
            for line in fsys:
                if line.startswith("NAME"):
                    tmp = line
                    os_name = tmp.split('=')[1].replace('"', '').replace('\n', '')
                    #break
                elif line.startswith("PRETTY_NAME"):
                    tmp = line
                    release_name = tmp.split('=')[1].replace('"', '').replace('\n', '')
    else:
        if os.path.exists(RELEASEPATH):
            with open(RELEASEPATH, "r") as fsys:
                for line in fsys:
                    if line.startswith("DISTRIB_ID"):
                        tmp = line
                        os_name = tmp.split('=')[1].replace('"', '').replace('\n', '')
                    elif line.startswith("DISTRIB_RELEASE"):
                        tmp = line
                        release_name = tmp.split('=')[1].replace('"', '').replace('\n', '')
                        #break
    return (os_name, release_name)

def get_desktop():
    '''
    获取桌面环境信息
    '''
    apt_cache = apt.Cache()
    try:
        package = apt_cache["kylin-menu"]
    except:
        package = None
    if package is not None and package.is_installed:
        return "UKUI"
    desktop_dict = {'ubuntu': 'Unity',
                    'ubuntu-2d': 'Unity 2D',
                    'gnome': 'GNOME Shell',
                    'gnome-classic': 'GNOME Classic',
                    'gnome-shell': 'GNOME Shell',
                    'gnome-fallback': 'GNOME Fallback',
                    'pantheon': 'elementary OS (Luna)',
                    'Lubutu': 'LXDE',
    }
    try:
        desktop_name = os.getenv('XDG_CURRENT_DESKTOP')
        if desktop_name is None:
            desktop_name = os.getenv('XDG_SESSION_DESKTOP')
        if desktop_name is None:
            desktop_name = "N/A"
        return desktop_name
    except Exception as e:
        desktop = os.getenv('DESKTOP_SESSION')
        if desktop in desktop_dict:
            return desktop_dict[desktop]
        else:
            if desktop:
                return 'Unknown (%s)' % desktop
            else:
                return 'Unknown'

def get_cpu():
    '''
    获取CPU信息
    '''
    cpu_info = None
    model_name = ''
    cpu_cores = 0
    # CPU
    machine = platform.machine()
    if machine == "aarch64":
        with open('/proc/cpuinfo') as f:
            for line in f:
                if line.strip():
                    if line.rstrip('\n').startswith('processor'):
                       cpu_cores += 1
    else:
        with open('/proc/cpuinfo') as f:
            for line in f:
                if line.strip():
                    if line.rstrip('\n').startswith('cpu cores'):
                       cpu_cores = int(line.rstrip('\n').split(':')[1].strip())
                       break
    with open('/proc/cpuinfo') as f:
        for line in f:
            if line.strip():
                if line.rstrip('\n').startswith('model name'):
                    model_name = line.rstrip('\n').split(':')[1].strip()
                    break
                elif line.rstrip('\n').startswith('Hardware'):
                    model_name = line.rstrip('\n').split(':')[1].strip()
                    break
    arch = " " + platform.architecture()[0]
    # 20161212
    if cpu_cores == 0:
        cpu_info = model_name
    #elif cpu_cores == 1:
    #    cpu_info = "Single core "  + model_name#单核
    #elif cpu_cores == 2:
    #    cpu_info = "Double cores "  + model_name#双核
    #elif cpu_cores == 3:
    #    cpu_info = "Three cores "  + model_name#三核
    #elif cpu_cores == 4:
    #    cpu_info = "Four cores "  + model_name#四核
    #else:
    #    cpu_info = str(cpu_cores) + "cores "  + model_name
    elif cpu_cores == 1:
        cpu_info = _("Single core ")  + model_name + arch#单核
    elif cpu_cores == 2:
        cpu_info = _("Double cores ")  + model_name + arch#双核
    elif cpu_cores == 3:
        cpu_info = _("Three cores ")  + model_name + arch#三核
    elif cpu_cores == 4:
        cpu_info = _("Four cores ")  + model_name + arch#四核
    else:
        cpu_info = str(cpu_cores) + _("cores ")  + model_name + arch
    return cpu_info

#def get_memory():
#    MemTotal2 = None
#    # Memory
#    with open('/proc/meminfo') as f:
#        for line in f:
#            if line.strip():
#                if line.rstrip('\n').startswith('MemTotal'):
#                    MemTotal = line.rstrip('\n').split(':')[1].strip()
#                    MemTotal1 = MemTotal.split(' ')[0]
##                    MemTotal1 = 8156252#7889972
#                    lst = ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB']
#                    i = int(math.floor(math.log(int(MemTotal1) * 1000, 1000)))
#                    if i >= len(lst):
#                        i = len(lst) - 1
#                    MemTotal2 = ('%.1f' + " " + lst[i]) % (int(MemTotal1) * 1000/math.pow(1000, i))
#                    #MemTotal2 = GLib.format_size_for_display(int(MemTotal1) * 1000)
#                    break
#    return str(MemTotal2)

def get_memory():
    '''
    获取内存信息
    '''
    MemSize = None
    # Memory
    with open('/proc/meminfo') as f:
        for line in f:
            if line.strip():
                if line.rstrip('\n').startswith('MemTotal'):
                    MemTotal = line.rstrip('\n').split(':')[1].strip()
                    MemTmp = MemTotal.split(' ')[0]
                    #print "MemTmp=",MemTmp
                    #MemTmp = 1000204886#8156252#7889972
                    #MemTmp = 3476412#8156252#7889972
                    MemSize = get_mem_human_read_capacity_size(int(MemTmp)*1024)
                    break
    if MemSize is None:
        return "N/A"
    else:
        return str(MemSize)


def get_hardware():
    '''
    获取硬盘信息，支持多个硬盘，包括固态硬盘
    '''
    hd_list = []
    fpath = os.path.expanduser("/sys/block/")
    for filepath in os.listdir(fpath):
        if filepath.startswith('loop') or filepath.startswith('ram') or filepath.startswith('.'):
            continue

        filename = "/sys/block/" + filepath +  os.path.sep + 'size'
        if os.path.exists(filename):
            try:
                fp = open(filename, "r")
                content = fp.read()
                content = content.strip('\n')
                fp.close()
                if int(content) == 0:
                    continue
                else:
                    hd_sector_size = 512
                    phyfilename = "/sys/block/" + filepath +  os.path.sep + 'queue/physical_block_size'
                    if os.path.exists(phyfilename):
                        fp = open(phyfilename, "r")
                        hd_sector_size = int(fp.read())
                        fp.close()
                    hd_list.append(get_human_read_capacity_size(int(content) * hd_sector_size))
            except Exception as e:
                continue

    if len(hd_list) > 0:
        hd_info =" + ".join(hd_list)
        return hd_info
    else:
        return "N/A"

#    n =  os.popen("ls /dev/sd?")
#    line = n.read()
#    n.close()
#    n = os.popen("ls /dev/hd?")
#    line += n.read()
#    n.close()
#    size_all = 0
#    if line :
#        line = line.split('\n')
#        for k in line :
#            if k :
#                disklist = []
#                status, output = commands.getstatusoutput("lsblk -ab")
#                for line in output.split("\n"):
#                    value = line.split()
#                    if len(value) > 5:
#                        dst = '/dev/' + value[0]
#                        if value[1] == "8:0" and value[5] == "disk" and dst == k:
#                            disklist.append(int(value[3]))
#                if not status and len(disklist) > 0:
#                    size_all += sum(disklist)
##                    size_all += (sum(disklist) / 1000 / 1000 / 1000)
#    if size_all > 0:
#        return get_human_read_capacity_size(int(size_all))
#    else:
#        if os.path.exists("/sys/block/nvme0n1/queue/physical_block_size"):
#            fp = open("/sys/block/nvme0n1/queue/physical_block_size", "r")
#            hd_sector_size = int(fp.read())
#            fp.close()
#        else:
#            hd_sector_size = 512

#        if os.path.exists("/sys/block/nvme0n1/size"):
#            fp = open("/sys/block/nvme0n1/size", "r")
#            hd_sectors = int(fp.read())
#            fp.close()
#        else:
#            hd_sectors = 0
#        if hd_sectors > 0:
#            return get_human_read_capacity_size(int(hd_sector_size*hd_sectors))
#        else:
#            return "N/A"


#    if size_all >= 1000:
#        size_all = size_all / 1000
#        return str(size_all) + " TB"
#    else:
#        return str(size_all) + " GB"

#def get_hardwareinfo():
#    cpu_info = None
#    model_name = ''
#    MemTotal2 = ''
#    cpu_cores = 1
#    # CPU
#    with open('/proc/cpuinfo') as f:
#        for line in f:
#            if line.strip():
#                if line.rstrip('\n').startswith('cpu cores'):
#                   cpu_cores = line.rstrip('\n').split(':')[1].strip()
#                   break
#    with open('/proc/cpuinfo') as f:
#        for line in f:
#            if line.strip():
#                if line.rstrip('\n').startswith('model name'):
#                    model_name = line.rstrip('\n').split(':')[1].strip()
#                    break
#                elif line.rstrip('\n').startswith('Hardware'):
#                    model_name = line.rstrip('\n').split(':')[1].strip()
#                    break
#    if cpu_cores == 1:
#        cpu_info = _("Single core ")  + model_name#单核
#    elif cpu_cores == 2:
#        cpu_info = _("Double cores ")  + model_name#双核
#    elif cpu_cores == 3:
#        cpu_info = _("Three cores ")  + model_name#三核
#    elif cpu_cores == 4:
#        cpu_info = _("Four cores ")  + model_name#四核
#    else:
#        cpu_info = cpu_cores + _("cores ")  + model_name
#    # Memory
#    with open('/proc/meminfo') as f:
#        for line in f:
#            if line.strip():
#                if line.rstrip('\n').startswith('MemTotal'):
#                    MemTotal = line.rstrip('\n').split(':')[1].strip()
#                    MemTotal1 = MemTotal.split(' ')[0]
#                    MemTotal2 = GLib.format_size_for_display(int(MemTotal1) * 1024)
#                    break
#    return cpu_info,MemTotal2

#def test_fun():
#    print GLib.get_user_name()


#print platform.platform()#Linux-3.14.0-kylin-20150410-phytium+-aarch64-with-NeoKylin-4.0-1a-ginkgo 操作系统
#print platform.node()#kylin  主机名
#print platform.system()#Linux   操作系统类型
#print platform.architecture()[0]#64bit  系统位数
#print platform.release()#3.14.0-kylin-20150410-phytium+   内核版本
#print platform.machine()#aarch64    内核架构
#print platform.processor()
#print GLib.get_user_name()#当前用户名
#get_user_info()
#get_distro()
#print get_desktop()#Unity
#print get_hardwareinfo()#(' Intel(R) Core(TM) i3-2350M CPU @ 2.30GHz', '7.6 GB')

INTERFACE = "com.kylin.computer"
PATH = "/"
HOME = os.path.expandvars('$HOME')


class Daemon(dbus.service.Object):
    def __init__ (self, mainloop):
        '''
        dbus进程初始化
        '''
        bus_name = dbus.service.BusName(INTERFACE, bus=dbus.SessionBus())
        dbus.service.Object.__init__(self, bus_name, PATH)
        self.mainloop = mainloop

    @dbus.service.method(INTERFACE, in_signature='', out_signature='ssssssss')
    def get_computer_info(self):
        '''
        获取系统信息
        '''
        (os_name, release_name) = get_os()
        kernel_name = platform.platform()
        login_user = GLib.get_user_name()
        desktop_type = get_desktop()
        cpu = get_cpu()
        memory = get_memory()
        hardcapacity = get_hardware()
        return (os_name, release_name, kernel_name, login_user, desktop_type, cpu, memory, hardcapacity)
        
    @dbus.service.method(INTERFACE, in_signature='', out_signature='')
    def exit(self):
        '''
        dbus退出函数
        '''
        self.mainloop.quit()

    @dbus.service.method(INTERFACE, in_signature='', out_signature='s')
    def call_computer_daemon(self):
        '''
        一个dbus的测试函数
        '''
        return "My Computer Property"

if __name__ == '__main__':
    '''
    主函数
    '''
    #t = threading.Timer(5.0, test_fun)
    #t.start()
    dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
    GObject.threads_init()
    zh_trans = gettext.translation('kylin-computer-viewer', locale_path, languages=['zh_CN'])
    zh_trans.install()
    mainloop = GObject.MainLoop()
    signal.signal(signal.SIGINT, lambda : mainloop.quit())
    Daemon(mainloop)
    mainloop.run()
